# ySanic
ySanic is a [Sanic](https://sanicframework.org/) subclass with a bunch of utilities to help the developer to work with it in the context of the yRest framework (which includes [yModel](https://github.com/Garito/yModel) and [yAuth](https://github.com/Garito/yAuth) by the moment and yOpenSanic in the future)

yBlueprint adds some decorators and route creators both for CRUD and tree models

# Example
In the tests folder there is an app with two models: Todos and Nodes
Todos shows how to program the typical plain structure while Nodes shows how to program the tree ones
If you respect the contract you could use the helpers (like the routes generators)

## Installation
```pip install ySanic```

## Help
Feel free to help if you think something is weird or incomplete by submiting a pull request

### What is already needed
- [] More testing
- [] Continous integration
- [] Better help & documentation

### I'm not a technical person but still want to help
You can tip the project with cryptos too:

BTC: 1GtKxwZGR65ar9V8xafxhMiniZyqXej2GC

ETH: 0x01bd478b8C07633D2f4E58AC553f72CE4E590d56

LTC: LYUzrFX6ck5uMhw5VqcD9piQHnX7oeSLdh

XMR: 49stcvbfjEkWLjb6mdG21zMJ3uRrLmN3bazGQ8cHjjsVHYYyY61N6P7emCXhpsvB2Vc8Uuz2FA1Qk6hkE8e4ADmJQQ64eyT

ADA: DdzFFzCqrhsoUF5UjGGAYUayV5uNCJZ17PJn9V8X9MTQ26m2wDVycme42gufKufPNWMazfJLg8RKHpc1iFvn6j8BTJjaozGtLPzCDx5t

NEM: NDGYO6X3NTD6CX3V7MCCYKQPBIOYGZRXEKDLCDW2
